==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebBaseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebBaseEventArgsDescription } from "./WebBaseEventArgsDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseEventArgsDescriptionMetadata, _super);
    function WebBaseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDescriptionMetadata.a == null) {
            WebBaseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDescriptionMetadata.c(WebBaseEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebBaseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebBaseEventArgsDescriptionMetadata.a);
        WebBaseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebBaseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebBaseEventArgsDetail");
    };
    WebBaseEventArgsDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDescriptionMetadata.b(a);
        a.aa("WebBaseEventArgs", function () { return new WebBaseEventArgsDescription(); });
        a.z("WebBaseEventArgs", WebBaseEventArgsDescriptionMetadata.a);
    };
    WebBaseEventArgsDescriptionMetadata.$t = markType(WebBaseEventArgsDescriptionMetadata, 'WebBaseEventArgsDescriptionMetadata');
    WebBaseEventArgsDescriptionMetadata.a = null;
    return WebBaseEventArgsDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebBaseEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebBaseEventArgsDescription } from "./WebBaseEventArgsDescription";
/**
 * @hidden
 */
var WebBaseEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebBaseEventArgsDescriptionMetadata, _super);
    function WebBaseEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebBaseEventArgsDescriptionMetadata.b = function (a) {
        if (WebBaseEventArgsDescriptionMetadata.a == null) {
            WebBaseEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebBaseEventArgsDescriptionMetadata.c(WebBaseEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebBaseEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebBaseEventArgsDescriptionMetadata.a);
        WebBaseEventArgsDetailDescriptionMetadata.d(a);
    };
    WebBaseEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:BaseEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebBaseEventArgsDetail");
    };
    WebBaseEventArgsDescriptionMetadata.d = function (a) {
        WebBaseEventArgsDescriptionMetadata.b(a);
        a.ac("WebBaseEventArgs", function () { return new WebBaseEventArgsDescription(); });
        a.ab("WebBaseEventArgs", WebBaseEventArgsDescriptionMetadata.a);
    };
    WebBaseEventArgsDescriptionMetadata.$t = markType(WebBaseEventArgsDescriptionMetadata, 'WebBaseEventArgsDescriptionMetadata');
    WebBaseEventArgsDescriptionMetadata.a = null;
    return WebBaseEventArgsDescriptionMetadata;
}(Base));
export { WebBaseEventArgsDescriptionMetadata };
